@@ -18,10 +18,11 @@ import argparse
 
 from oslo_serialization import jsonutils
 
+from neutronclient._i18n import _
 from neutronclient.common import exceptions
 from neutronclient.common import utils
-from neutronclient.i18n import _
 from neutronclient.neutron import v2_0 as neutronV20
+from neutronclient.neutron.v2_0 import dns
 from neutronclient.neutron.v2_0.qos import policy as qos_policy
 
 
@@ -46,6 +47,7 @@ def _add_updatable_args(parser):
     parser.add_argument(
         '--fixed-ip', metavar='subnet_id=SUBNET,ip_address=IP_ADDR',
         action='append',
+        type=utils.str2dict_type(optional_keys=['subnet_id', 'ip_address']),
         help=_('Desired IP and/or subnet for this port: '
                'subnet_id=<name_or_id>,ip_address=<ip>. '
                'You can repeat this option.'))
@@ -68,24 +70,19 @@ def _add_updatable_args(parser):
 
 
 def _updatable_args2body(parsed_args, body, client):
-    if parsed_args.device_id:
-        body['port'].update({'device_id': parsed_args.device_id})
-    if parsed_args.device_owner:
-        body['port'].update({'device_owner': parsed_args.device_owner})
-    if parsed_args.name:
-        body['port'].update({'name': parsed_args.name})
+    neutronV20.update_dict(parsed_args, body,
+                           ['device_id', 'device_owner', 'name'])
     ips = []
     if parsed_args.fixed_ip:
         for ip_spec in parsed_args.fixed_ip:
-            ip_dict = utils.str2dict(ip_spec)
-            if 'subnet_id' in ip_dict:
-                subnet_name_id = ip_dict['subnet_id']
+            if 'subnet_id' in ip_spec:
+                subnet_name_id = ip_spec['subnet_id']
                 _subnet_id = neutronV20.find_resourceid_by_name_or_id(
                     client, 'subnet', subnet_name_id)
-                ip_dict['subnet_id'] = _subnet_id
-            ips.append(ip_dict)
+                ip_spec['subnet_id'] = _subnet_id
+            ips.append(ip_spec)
     if ips:
-        body['port'].update({'fixed_ips': ips})
+        body['fixed_ips'] = ips
 
 
 class ListPort(neutronV20.ListCommand):
@@ -111,17 +108,16 @@ class ListRouterPort(neutronV20.ListCommand):
     def get_parser(self, prog_name):
         parser = super(ListRouterPort, self).get_parser(prog_name)
         parser.add_argument(
-            'id', metavar='router',
+            'id', metavar='ROUTER',
             help=_('ID or name of router to look up.'))
         return parser
 
-    def get_data(self, parsed_args):
+    def take_action(self, parsed_args):
         neutron_client = self.get_client()
-        neutron_client.format = parsed_args.request_format
         _id = neutronV20.find_resourceid_by_name_or_id(
             neutron_client, 'router', parsed_args.id)
         self.values_specs.append('--device_id=%s' % _id)
-        return super(ListRouterPort, self).get_data(parsed_args)
+        return super(ListRouterPort, self).take_action(parsed_args)
 
 
 class ShowPort(neutronV20.ShowCommand):
@@ -163,6 +159,9 @@ class UpdateExtraDhcpOptMixin(object):
             default=[],
             action='append',
             dest='extra_dhcp_opts',
+            type=utils.str2dict_type(
+                required_keys=['opt_name'],
+                optional_keys=['opt_value', 'ip_version']),
             help=_('Extra dhcp options to be assigned to this port: '
                    'opt_name=<dhcp_option_name>,opt_value=<value>,'
                    'ip_version={4,6}. You can repeat this option.'))
@@ -179,7 +178,7 @@ class UpdateExtraDhcpOptMixin(object):
                             "ip_version={4,6}. "
                             "You can repeat this option.")
             for opt in parsed_args.extra_dhcp_opts:
-                opt_ele.update(utils.str2dict(opt))
+                opt_ele.update(opt)
                 if ('opt_name' in opt_ele and
                         ('opt_value' in opt_ele or 'ip_version' in opt_ele)):
                     if opt_ele.get('opt_value') == 'null':
@@ -190,11 +189,40 @@ class UpdateExtraDhcpOptMixin(object):
                     raise exceptions.CommandError(edo_err_msg)
 
         if ops:
-            port.update({'extra_dhcp_opts': ops})
+            port['extra_dhcp_opts'] = ops
+
+
+class UpdatePortAllowedAddressPair(object):
+    """Update Port for allowed_address_pairs"""
+
+    def add_arguments_allowedaddresspairs(self, parser):
+        group_aap = parser.add_mutually_exclusive_group()
+        group_aap.add_argument(
+            '--allowed-address-pair',
+            metavar='ip_address=IP_ADDR[,mac_address=MAC_ADDR]',
+            default=[],
+            action='append',
+            dest='allowed_address_pairs',
+            type=utils.str2dict_type(
+                required_keys=['ip_address'],
+                optional_keys=['mac_address']),
+            help=_('Allowed address pair associated with the port.'
+                   'You can repeat this option.'))
+        group_aap.add_argument(
+            '--no-allowed-address-pairs',
+            action='store_true',
+            help=_('Associate no allowed address pairs with the port.'))
+
+    def args2body_allowedaddresspairs(self, parsed_args, port):
+        if parsed_args.allowed_address_pairs:
+            port['allowed_address_pairs'] = parsed_args.allowed_address_pairs
+        elif parsed_args.no_allowed_address_pairs:
+            port['allowed_address_pairs'] = []
 
 
 class CreatePort(neutronV20.CreateCommand, UpdatePortSecGroupMixin,
-                 UpdateExtraDhcpOptMixin, qos_policy.CreateQosPolicyMixin):
+                 UpdateExtraDhcpOptMixin, qos_policy.CreateQosPolicyMixin,
+                 UpdatePortAllowedAddressPair):
     """Create a port for a given tenant."""
 
     resource = 'port'
@@ -216,12 +244,16 @@ class CreatePort(neutronV20.CreateCommand, UpdatePortSecGroupMixin,
             '--mac_address',
             help=argparse.SUPPRESS)
         parser.add_argument(
-            '--vnic-type', metavar='<direct | macvtap | normal>',
-            choices=['direct', 'macvtap', 'normal'],
+            '--vnic-type',
+            metavar='<direct | direct-physical | macvtap '
+                    '| normal | baremetal>',
+            choices=['direct', 'direct-physical', 'macvtap',
+                     'normal', 'baremetal'],
             help=_('VNIC type for this port.'))
         parser.add_argument(
             '--vnic_type',
-            choices=['direct', 'macvtap', 'normal'],
+            choices=['direct', 'direct-physical', 'macvtap',
+                     'normal', 'baremetal'],
             help=argparse.SUPPRESS)
         parser.add_argument(
             '--binding-profile',
@@ -232,33 +264,35 @@ class CreatePort(neutronV20.CreateCommand, UpdatePortSecGroupMixin,
         self.add_arguments_secgroup(parser)
         self.add_arguments_extradhcpopt(parser)
         self.add_arguments_qos_policy(parser)
+        self.add_arguments_allowedaddresspairs(parser)
 
         parser.add_argument(
             'network_id', metavar='NETWORK',
             help=_('Network ID or name this port belongs to.'))
+        dns.add_dns_argument_create(parser, self.resource, 'name')
 
     def args2body(self, parsed_args):
         client = self.get_client()
         _network_id = neutronV20.find_resourceid_by_name_or_id(
             client, 'network', parsed_args.network_id)
-        body = {'port': {'admin_state_up': parsed_args.admin_state,
-                         'network_id': _network_id, }, }
+        body = {'admin_state_up': parsed_args.admin_state,
+                'network_id': _network_id, }
         _updatable_args2body(parsed_args, body, client)
-        if parsed_args.mac_address:
-            body['port'].update({'mac_address': parsed_args.mac_address})
-        if parsed_args.tenant_id:
-            body['port'].update({'tenant_id': parsed_args.tenant_id})
+        neutronV20.update_dict(parsed_args, body,
+                               ['mac_address', 'tenant_id'])
         if parsed_args.vnic_type:
-            body['port'].update({'binding:vnic_type': parsed_args.vnic_type})
+            body['binding:vnic_type'] = parsed_args.vnic_type
         if parsed_args.binding_profile:
-            body['port'].update({'binding:profile':
-                                 jsonutils.loads(parsed_args.binding_profile)})
+            body['binding:profile'] = jsonutils.loads(
+                parsed_args.binding_profile)
 
-        self.args2body_secgroup(parsed_args, body['port'])
-        self.args2body_extradhcpopt(parsed_args, body['port'])
-        self.args2body_qos_policy(parsed_args, body['port'])
+        self.args2body_secgroup(parsed_args, body)
+        self.args2body_extradhcpopt(parsed_args, body)
+        self.args2body_qos_policy(parsed_args, body)
+        self.args2body_allowedaddresspairs(parsed_args, body)
+        dns.args2body_dns_create(parsed_args, body, 'name')
 
-        return body
+        return {'port': body}
 
 
 class DeletePort(neutronV20.DeleteCommand):
@@ -268,7 +302,8 @@ class DeletePort(neutronV20.DeleteCommand):
 
 
 class UpdatePort(neutronV20.UpdateCommand, UpdatePortSecGroupMixin,
-                 UpdateExtraDhcpOptMixin, qos_policy.UpdateQosPolicyMixin):
+                 UpdateExtraDhcpOptMixin, qos_policy.UpdateQosPolicyMixin,
+                 UpdatePortAllowedAddressPair):
     """Update port's information."""
 
     resource = 'port'
@@ -286,17 +321,20 @@ class UpdatePort(neutronV20.UpdateCommand, UpdatePortSecGroupMixin,
         self.add_arguments_secgroup(parser)
         self.add_arguments_extradhcpopt(parser)
         self.add_arguments_qos_policy(parser)
+        self.add_arguments_allowedaddresspairs(parser)
+        dns.add_dns_argument_update(parser, self.resource, 'name')
 
     def args2body(self, parsed_args):
-        body = {'port': {}}
+        body = {}
         client = self.get_client()
         _updatable_args2body(parsed_args, body, client)
         if parsed_args.admin_state_up:
-            body['port'].update({'admin_state_up':
-                                parsed_args.admin_state_up})
+            body['admin_state_up'] = parsed_args.admin_state_up
 
-        self.args2body_secgroup(parsed_args, body['port'])
-        self.args2body_extradhcpopt(parsed_args, body['port'])
-        self.args2body_qos_policy(parsed_args, body['port'])
+        self.args2body_secgroup(parsed_args, body)
+        self.args2body_extradhcpopt(parsed_args, body)
+        self.args2body_qos_policy(parsed_args, body)
+        self.args2body_allowedaddresspairs(parsed_args, body)
+        dns.args2body_dns_update(parsed_args, body, 'name')
 
-        return body
+        return {'port': body}
