@@ -18,9 +18,9 @@ import argparse
 
 from oslo_serialization import jsonutils
 
+from neutronclient._i18n import _
 from neutronclient.common import exceptions
 from neutronclient.common import utils
-from neutronclient.i18n import _
 from neutronclient.neutron import v2_0 as neutronV20
 
 
@@ -62,16 +62,19 @@ def add_updatable_arguments(parser):
         help=_('No distribution of gateway.'))
     parser.add_argument(
         '--allocation-pool', metavar='start=IP_ADDR,end=IP_ADDR',
-        action='append', dest='allocation_pools', type=utils.str2dict,
+        action='append', dest='allocation_pools',
+        type=utils.str2dict_type(required_keys=['start', 'end']),
         help=_('Allocation pool IP addresses for this subnet '
                '(This option can be repeated).'))
     parser.add_argument(
         '--allocation_pool',
-        action='append', dest='allocation_pools', type=utils.str2dict,
+        action='append', dest='allocation_pools',
+        type=utils.str2dict_type(required_keys=['start', 'end']),
         help=argparse.SUPPRESS)
     parser.add_argument(
         '--host-route', metavar='destination=CIDR,nexthop=IP_ADDR',
-        action='append', dest='host_routes', type=utils.str2dict,
+        action='append', dest='host_routes',
+        type=utils.str2dict_type(required_keys=['destination', 'nexthop']),
         help=_('Additional route (This option can be repeated).'))
     parser.add_argument(
         '--dns-nameserver', metavar='DNS_NAMESERVER',
@@ -107,33 +110,28 @@ def updatable_args2body(parsed_args, body, for_create=True, ip_version=None):
         raise exceptions.CommandError(_(
             "You cannot enable and disable DHCP at the same time."))
 
+    neutronV20.update_dict(parsed_args, body,
+                           ['name', 'allocation_pools',
+                            'host_routes', 'dns_nameservers'])
     if parsed_args.no_gateway:
-        body['subnet'].update({'gateway_ip': None})
+        body['gateway_ip'] = None
     elif parsed_args.gateway:
-        body['subnet'].update({'gateway_ip': parsed_args.gateway})
-    if parsed_args.name:
-        body['subnet'].update({'name': parsed_args.name})
+        body['gateway_ip'] = parsed_args.gateway
     if parsed_args.disable_dhcp:
-        body['subnet'].update({'enable_dhcp': False})
+        body['enable_dhcp'] = False
     if parsed_args.enable_dhcp:
-        body['subnet'].update({'enable_dhcp': True})
-    if parsed_args.allocation_pools:
-        body['subnet']['allocation_pools'] = parsed_args.allocation_pools
-    if parsed_args.host_routes:
-        body['subnet']['host_routes'] = parsed_args.host_routes
-    if parsed_args.dns_nameservers:
-        body['subnet']['dns_nameservers'] = parsed_args.dns_nameservers
+        body['enable_dhcp'] = True
     if for_create and parsed_args.ipv6_ra_mode:
         if ip_version == 4:
             raise exceptions.CommandError(_("--ipv6-ra-mode is invalid "
                                             "when --ip-version is 4"))
-        body['subnet']['ipv6_ra_mode'] = parsed_args.ipv6_ra_mode
+        body['ipv6_ra_mode'] = parsed_args.ipv6_ra_mode
     if for_create and parsed_args.ipv6_address_mode:
         if ip_version == 4:
             raise exceptions.CommandError(_("--ipv6-address-mode is "
                                             "invalid when --ip-version "
                                             "is 4"))
-        body['subnet']['ipv6_address_mode'] = parsed_args.ipv6_address_mode
+        body['ipv6_address_mode'] = parsed_args.ipv6_address_mode
 
 
 class ListSubnet(neutronV20.ListCommand):
@@ -192,6 +190,10 @@ class CreateSubnet(neutronV20.CreateCommand):
             '--subnetpool', metavar='SUBNETPOOL',
             help=_('ID or name of subnetpool from which this subnet '
                    'will obtain a CIDR.'))
+        parser.add_argument(
+            '--use-default-subnetpool',
+            action='store_true',
+            help=_('Use default subnetpool for ip_version, if it exists.'))
         parser.add_argument(
             '--prefixlen', metavar='PREFIX_LENGTH',
             help=_('Prefix length for subnet allocation from subnetpool.'))
@@ -199,11 +201,13 @@ class CreateSubnet(neutronV20.CreateCommand):
     def args2body(self, parsed_args):
         _network_id = neutronV20.find_resourceid_by_name_or_id(
             self.get_client(), 'network', parsed_args.network_id)
-        body = {'subnet': {'network_id': _network_id}}
+        body = {'network_id': _network_id}
 
         if parsed_args.prefixlen:
-            body['subnet'].update({'prefixlen': parsed_args.prefixlen})
+            body['prefixlen'] = parsed_args.prefixlen
         ip_version = parsed_args.ip_version
+        if parsed_args.use_default_subnetpool:
+            body['use_default_subnetpool'] = True
         if parsed_args.subnetpool:
             if parsed_args.subnetpool == 'None':
                 _subnetpool_id = None
@@ -214,16 +218,16 @@ class CreateSubnet(neutronV20.CreateCommand):
                 # Now that we have the pool_id - let's just have a check on the
                 # ip version used in the pool
                 ip_version = _subnetpool['ip_version']
-            body['subnet'].update({'subnetpool_id': _subnetpool_id})
+            body['subnetpool_id'] = _subnetpool_id
 
         # IP version needs to be set as IP version can be
         # determined by subnetpool.
-        body['subnet']['ip_version'] = ip_version
+        body['ip_version'] = ip_version
 
         if parsed_args.cidr:
             # With subnetpool, cidr is now optional for creating subnet.
             cidr = parsed_args.cidr
-            body['subnet'].update({'cidr': cidr})
+            body['cidr'] = cidr
             unusable_cidr = '/32' if ip_version == 4 else '/128'
             if cidr.endswith(unusable_cidr):
                 self.log.warning(_("An IPv%(ip)d subnet with a %(cidr)s CIDR "
@@ -235,9 +239,9 @@ class CreateSubnet(neutronV20.CreateCommand):
 
         updatable_args2body(parsed_args, body, ip_version=ip_version)
         if parsed_args.tenant_id:
-            body['subnet'].update({'tenant_id': parsed_args.tenant_id})
+            body['tenant_id'] = parsed_args.tenant_id
 
-        return body
+        return {'subnet': body}
 
 
 class DeleteSubnet(neutronV20.DeleteCommand):
@@ -255,6 +259,6 @@ class UpdateSubnet(neutronV20.UpdateCommand):
         add_updatable_arguments(parser)
 
     def args2body(self, parsed_args):
-        body = {'subnet': {}}
+        body = {}
         updatable_args2body(parsed_args, body, for_create=False)
-        return body
+        return {'subnet': body}
