@@ -14,8 +14,8 @@
 #    under the License.
 #
 
+from neutronclient._i18n import _
 from neutronclient.common import utils
-from neutronclient.i18n import _
 from neutronclient.neutron import v2_0 as neutronv20
 from neutronclient.neutron.v2_0.vpn import utils as vpn_utils
 
@@ -35,6 +35,7 @@ class ShowIPsecPolicy(neutronv20.ShowCommand):
     """Show information of a given IPsec policy."""
 
     resource = 'ipsecpolicy'
+    help_resource = 'IPsec policy'
 
 
 class CreateIPsecPolicy(neutronv20.CreateCommand):
@@ -69,7 +70,7 @@ class CreateIPsecPolicy(neutronv20.CreateCommand):
         parser.add_argument(
             '--lifetime',
             metavar="units=UNITS,value=VALUE",
-            type=utils.str2dict,
+            type=utils.str2dict_type(optional_keys=['units', 'value']),
             help=vpn_utils.lifetime_help("IPsec"))
         parser.add_argument(
             'name', metavar='NAME',
@@ -77,50 +78,41 @@ class CreateIPsecPolicy(neutronv20.CreateCommand):
 
     def args2body(self, parsed_args):
 
-        body = {'ipsecpolicy': {
-            'auth_algorithm': parsed_args.auth_algorithm,
-            'encryption_algorithm': parsed_args.encryption_algorithm,
-            'encapsulation_mode': parsed_args.encapsulation_mode,
-            'transform_protocol': parsed_args.transform_protocol,
-            'pfs': parsed_args.pfs,
-        }, }
-        if parsed_args.name:
-            body['ipsecpolicy'].update({'name': parsed_args.name})
-        if parsed_args.description:
-            body['ipsecpolicy'].update(
-                {'description': parsed_args.description}
-            )
-        if parsed_args.tenant_id:
-            body['ipsecpolicy'].update({'tenant_id': parsed_args.tenant_id})
+        body = {}
+        neutronv20.update_dict(parsed_args, body,
+                               ['auth_algorithm', 'encryption_algorithm',
+                                'encapsulation_mode', 'transform_protocol',
+                                'pfs', 'name', 'description', 'tenant_id'])
         if parsed_args.lifetime:
             vpn_utils.validate_lifetime_dict(parsed_args.lifetime)
-            body['ipsecpolicy'].update({'lifetime': parsed_args.lifetime})
-        return body
+            body['lifetime'] = parsed_args.lifetime
+        return {'ipsecpolicy': body}
 
 
 class UpdateIPsecPolicy(neutronv20.UpdateCommand):
     """Update a given IPsec policy."""
 
     resource = 'ipsecpolicy'
+    help_resource = 'IPsec policy'
 
     def add_known_arguments(self, parser):
         parser.add_argument(
             '--lifetime',
             metavar="units=UNITS,value=VALUE",
-            type=utils.str2dict,
+            type=utils.str2dict_type(optional_keys=['units', 'value']),
             help=vpn_utils.lifetime_help("IPsec"))
 
     def args2body(self, parsed_args):
 
-        body = {'ipsecpolicy': {
-        }, }
+        body = {}
         if parsed_args.lifetime:
             vpn_utils.validate_lifetime_dict(parsed_args.lifetime)
-            body['ipsecpolicy'].update({'lifetime': parsed_args.lifetime})
-        return body
+            body['lifetime'] = parsed_args.lifetime
+        return {'ipsecpolicy': body}
 
 
 class DeleteIPsecPolicy(neutronv20.DeleteCommand):
     """Delete a given IPsec policy."""
 
     resource = 'ipsecpolicy'
+    help_resource = 'IPsec policy'
