@@ -24,7 +24,7 @@ from neutronclient.tests.unit import test_cli20
 
 class CLITestV20LbHealthmonitorJSON(test_cli20.CLITestV20Base):
     def test_create_healthmonitor_with_mandatory_params(self):
-        """lb-healthmonitor-create with mandatory params only."""
+        # lb-healthmonitor-create with mandatory params only.
         resource = 'health_monitor'
         cmd = healthmonitor.CreateHealthMonitor(test_cli20.MyApp(sys.stdout),
                                                 None)
@@ -49,7 +49,7 @@ class CLITestV20LbHealthmonitorJSON(test_cli20.CLITestV20Base):
                                    position_names, position_values)
 
     def test_create_healthmonitor_with_all_params(self):
-        """lb-healthmonitor-create with all params set."""
+        # lb-healthmonitor-create with all params set.
         resource = 'health_monitor'
         cmd = healthmonitor.CreateHealthMonitor(test_cli20.MyApp(sys.stdout),
                                                 None)
@@ -84,23 +84,22 @@ class CLITestV20LbHealthmonitorJSON(test_cli20.CLITestV20Base):
                                    position_names, position_values)
 
     def test_list_healthmonitors(self):
-        """lb-healthmonitor-list."""
+        # lb-healthmonitor-list.
         resources = "health_monitors"
         cmd = healthmonitor.ListHealthMonitor(test_cli20.MyApp(sys.stdout),
                                               None)
         self._test_list_resources(resources, cmd, True)
 
     def test_list_healthmonitors_pagination(self):
-        """lb-healthmonitor-list."""
+        # lb-healthmonitor-list.
         resources = "health_monitors"
         cmd = healthmonitor.ListHealthMonitor(test_cli20.MyApp(sys.stdout),
                                               None)
         self._test_list_resources_with_pagination(resources, cmd)
 
     def test_list_healthmonitors_sort(self):
-        """lb-healthmonitor-list --sort-key name --sort-key id --sort-key asc
-        --sort-key desc
-        """
+        # lb-healthmonitor-list --sort-key name --sort-key id --sort-key asc
+        # --sort-key desc
         resources = "health_monitors"
         cmd = healthmonitor.ListHealthMonitor(test_cli20.MyApp(sys.stdout),
                                               None)
@@ -109,14 +108,14 @@ class CLITestV20LbHealthmonitorJSON(test_cli20.CLITestV20Base):
                                   sort_dir=["asc", "desc"])
 
     def test_list_healthmonitors_limit(self):
-        """lb-healthmonitor-list -P."""
+        # lb-healthmonitor-list -P.
         resources = "health_monitors"
         cmd = healthmonitor.ListHealthMonitor(test_cli20.MyApp(sys.stdout),
                                               None)
         self._test_list_resources(resources, cmd, page_size=1000)
 
     def test_show_healthmonitor_id(self):
-        """lb-healthmonitor-show test_id."""
+        # lb-healthmonitor-show test_id.
         resource = 'health_monitor'
         cmd = healthmonitor.ShowHealthMonitor(test_cli20.MyApp(sys.stdout),
                                               None)
@@ -124,7 +123,7 @@ class CLITestV20LbHealthmonitorJSON(test_cli20.CLITestV20Base):
         self._test_show_resource(resource, cmd, self.test_id, args, ['id'])
 
     def test_update_health_monitor(self):
-        """lb-healthmonitor-update  myid --name myname --tags a b."""
+        # lb-healthmonitor-update  myid --name myname --tags a b.
         resource = 'health_monitor'
         cmd = healthmonitor.UpdateHealthMonitor(test_cli20.MyApp(sys.stdout),
                                                 None)
@@ -133,7 +132,7 @@ class CLITestV20LbHealthmonitorJSON(test_cli20.CLITestV20Base):
                                    {'timeout': '5', })
 
     def test_delete_healthmonitor(self):
-        """lb-healthmonitor-delete my-id."""
+        # lb-healthmonitor-delete my-id."""
         resource = 'health_monitor'
         cmd = healthmonitor.DeleteHealthMonitor(test_cli20.MyApp(sys.stdout),
                                                 None)
@@ -201,7 +200,3 @@ class CLITestV20LbHealthmonitorJSON(test_cli20.CLITestV20Base):
         cmd.run(parsed_args)
         self.mox.VerifyAll()
         self.mox.UnsetStubs()
-
-
-class CLITestV20LbHealthmonitorXML(CLITestV20LbHealthmonitorJSON):
-    format = 'xml'
